"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.SuiAddress = exports.ensureFullSuiAddress = exports.SuiZeroAddress = void 0;
const connect_sdk_1 = require("@wormhole-foundation/connect-sdk");
const constants_1 = require("./constants");
const platform_1 = require("./platform");
const types_1 = require("./types");
exports.SuiZeroAddress = "0x";
// Sometimes Sui addresses will be trimmed of leading 0s
// add them back if necessary
function ensureFullSuiAddress(address) {
    if (address.length % 2 !== 0 || address.length < 66) {
        address = address.startsWith("0x") ? address.slice(2) : address;
        return "0x" + address.padStart(64, "0");
    }
    return address;
}
exports.ensureFullSuiAddress = ensureFullSuiAddress;
class SuiAddress {
    static byteSize = 32;
    platform = platform_1.SuiPlatform._platform;
    // Full 32 bytes of Address
    address;
    // Optional module and contract name
    module;
    constructor(address) {
        if (SuiAddress.instanceof(address)) {
            this.address = address.address;
            this.module = address.module;
        }
        else if (connect_sdk_1.UniversalAddress.instanceof(address)) {
            this.address = address.toUint8Array();
        }
        else if (typeof address === "string") {
            // If we've got an address of the form `0x1234...::module::...` then
            // stuff anything after the first `::` into the module field
            // and continue processing the address
            if ((0, types_1.isValidSuiType)(address)) {
                const chunks = address.split(constants_1.SUI_SEPARATOR);
                this.module = chunks.slice(1).join(constants_1.SUI_SEPARATOR);
                address = chunks[0];
            }
            address = ensureFullSuiAddress(address);
            if (!connect_sdk_1.encoding.hex.valid(address))
                throw new Error("Invalid Sui address: " + address);
            this.address = connect_sdk_1.encoding.hex.decode(address);
        }
        else {
            this.address = address;
        }
    }
    unwrap() {
        const addr = connect_sdk_1.encoding.hex.encode(this.address).replace(/^0+/, "");
        const module = this.module ? constants_1.SUI_SEPARATOR + this.module : "";
        return `0x${addr}${module}`;
    }
    toString() {
        return this.unwrap();
    }
    toNative() {
        return this;
    }
    toUint8Array() {
        return this.address;
    }
    toUniversalAddress() {
        return new connect_sdk_1.UniversalAddress(this.toUint8Array());
    }
    static instanceof(address) {
        return address.platform === platform_1.SuiPlatform._platform;
    }
    equals(other) {
        if (SuiAddress.instanceof(other)) {
            return other.unwrap() === this.unwrap();
        }
        else {
            return this.toUniversalAddress().equals(other);
        }
    }
}
exports.SuiAddress = SuiAddress;
(0, connect_sdk_1.registerNative)(types_1._platform, SuiAddress);
//# sourceMappingURL=address.js.map