"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.isValidSuiType = exports.isMoveStructObject = exports.isMoveStructStruct = exports.isMoveStructArray = exports.isSuiPublishEvent = exports.isSuiCreateEvent = exports.isSameType = exports.getFieldsFromObjectResponse = exports.getTableKeyType = exports.getPackageIdFromType = exports.getCoinTypeFromPackageId = exports.normalizeSuiType = exports.trimSuiType = exports._platform = void 0;
const utils_1 = require("@mysten/sui.js/utils");
const constants_1 = require("./constants");
exports._platform = "Sui";
const trimSuiType = (type) => type.replace(/(0x)(0*)/g, "0x");
exports.trimSuiType = trimSuiType;
const normalizeSuiType = (type) => {
    const tokens = type.split(constants_1.SUI_SEPARATOR);
    if (tokens.length !== 3)
        throw new Error(`Invalid Sui type: ${type}`);
    return [(0, utils_1.normalizeSuiAddress)(tokens[0]), tokens[1], tokens[2]].join(constants_1.SUI_SEPARATOR);
};
exports.normalizeSuiType = normalizeSuiType;
const getCoinTypeFromPackageId = (coinPackageId) => {
    if (!(0, utils_1.isValidSuiAddress)(coinPackageId))
        throw new Error(`Invalid package ID: ${coinPackageId}`);
    return [coinPackageId, "coin", "COIN"].join(constants_1.SUI_SEPARATOR);
};
exports.getCoinTypeFromPackageId = getCoinTypeFromPackageId;
const getPackageIdFromType = (type) => {
    if (!(0, exports.isValidSuiType)(type))
        throw new Error("Invalid Sui type" + type);
    const packageId = type.split(constants_1.SUI_SEPARATOR)[0];
    if (!packageId || !(0, utils_1.isValidSuiAddress)(packageId))
        throw new Error("Invalid package id: " + packageId);
    return packageId;
};
exports.getPackageIdFromType = getPackageIdFromType;
const getTableKeyType = (tableType) => {
    const match = (0, exports.trimSuiType)(tableType).match(/0x2::table::Table<(.*)>/);
    if (!match)
        throw new Error(`Invalid table type: ${tableType}`);
    if (match.length < 2)
        throw new Error(`Invalid table type: ${tableType}`);
    const [keyType] = match[1].split(",");
    if (!keyType || !(0, exports.isValidSuiType)(keyType))
        throw new Error(`Invalid key type: ${keyType}`);
    return keyType;
};
exports.getTableKeyType = getTableKeyType;
const getFieldsFromObjectResponse = (object) => {
    const content = object.data?.content;
    return content && content.dataType === "moveObject" ? content.fields : null;
};
exports.getFieldsFromObjectResponse = getFieldsFromObjectResponse;
const isSameType = (a, b) => {
    try {
        return (0, exports.normalizeSuiType)(a) === (0, exports.normalizeSuiType)(b);
    }
    catch {
        return false;
    }
};
exports.isSameType = isSameType;
// Event typeguard helpers
const isSuiCreateEvent = (event) => event?.type === "created";
exports.isSuiCreateEvent = isSuiCreateEvent;
const isSuiPublishEvent = (event) => event?.type === "published";
exports.isSuiPublishEvent = isSuiPublishEvent;
//
// MoveStruct typeguard helpers
//
function isMoveStructArray(value) {
    return Array.isArray(value);
}
exports.isMoveStructArray = isMoveStructArray;
function isMoveStructStruct(value) {
    return !Array.isArray(value) && typeof value === "object" && "fields" in value && "type" in value;
}
exports.isMoveStructStruct = isMoveStructStruct;
function isMoveStructObject(value) {
    return typeof value === "object" && !isMoveStructArray(value) && !isMoveStructStruct(value);
}
exports.isMoveStructObject = isMoveStructObject;
const isValidSuiType = (str) => /^(0x)?[0-9a-fA-F]+::\w+::\w+$/.test(str);
exports.isValidSuiType = isValidSuiType;
//# sourceMappingURL=types.js.map