import { isValidSuiAddress, normalizeSuiAddress } from "@mysten/sui.js/utils";
import { SUI_SEPARATOR } from "./constants";
export const _platform = "Sui";
export const trimSuiType = (type) => type.replace(/(0x)(0*)/g, "0x");
export const normalizeSuiType = (type) => {
    const tokens = type.split(SUI_SEPARATOR);
    if (tokens.length !== 3)
        throw new Error(`Invalid Sui type: ${type}`);
    return [normalizeSuiAddress(tokens[0]), tokens[1], tokens[2]].join(SUI_SEPARATOR);
};
export const getCoinTypeFromPackageId = (coinPackageId) => {
    if (!isValidSuiAddress(coinPackageId))
        throw new Error(`Invalid package ID: ${coinPackageId}`);
    return [coinPackageId, "coin", "COIN"].join(SUI_SEPARATOR);
};
export const getPackageIdFromType = (type) => {
    if (!isValidSuiType(type))
        throw new Error("Invalid Sui type" + type);
    const packageId = type.split(SUI_SEPARATOR)[0];
    if (!packageId || !isValidSuiAddress(packageId))
        throw new Error("Invalid package id: " + packageId);
    return packageId;
};
export const getTableKeyType = (tableType) => {
    const match = trimSuiType(tableType).match(/0x2::table::Table<(.*)>/);
    if (!match)
        throw new Error(`Invalid table type: ${tableType}`);
    if (match.length < 2)
        throw new Error(`Invalid table type: ${tableType}`);
    const [keyType] = match[1].split(",");
    if (!keyType || !isValidSuiType(keyType))
        throw new Error(`Invalid key type: ${keyType}`);
    return keyType;
};
export const getFieldsFromObjectResponse = (object) => {
    const content = object.data?.content;
    return content && content.dataType === "moveObject" ? content.fields : null;
};
export const isSameType = (a, b) => {
    try {
        return normalizeSuiType(a) === normalizeSuiType(b);
    }
    catch {
        return false;
    }
};
// Event typeguard helpers
export const isSuiCreateEvent = (event) => event?.type === "created";
export const isSuiPublishEvent = (event) => event?.type === "published";
//
// MoveStruct typeguard helpers
//
export function isMoveStructArray(value) {
    return Array.isArray(value);
}
export function isMoveStructStruct(value) {
    return !Array.isArray(value) && typeof value === "object" && "fields" in value && "type" in value;
}
export function isMoveStructObject(value) {
    return typeof value === "object" && !isMoveStructArray(value) && !isMoveStructStruct(value);
}
export const isValidSuiType = (str) => /^(0x)?[0-9a-fA-F]+::\w+::\w+$/.test(str);
//# sourceMappingURL=types.js.map